<?php

return array(
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Nijedan',
    'Edit' => 'Izmeni',
    'Remove' => 'Ukloni',
    'Yes' => 'Da',
    'No' => 'Ne',
    'cancel' => 'odustani',
    'or' => 'ili',
    'Yellow' => 'Žuta',
    'Blue' => 'Plava',
    'Green' => 'Zelena',
    'Purple' => 'Ljubičasta',
    'Red' => 'Crvena',
    'Orange' => 'Narandžasta',
    'Grey' => 'Siva',
    'Brown' => 'Braon',
    'Deep Orange' => 'Tamno naradžasta',
    'Dark Grey' => 'Tamno siva',
    'Pink' => 'Roze',
    'Teal' => 'Tirkizna',
    'Cyan' => 'Cijan',
    'Lime' => 'Limeta',
    'Light Green' => 'Svetlo zelena',
    'Amber' => 'Ćilibar',
    'Save' => 'Snimi',
    'Login' => 'Prijava',
    'Official website:' => 'Zvanična strana:',
    'Unassigned' => 'Nedodeljen',
    'View this task' => 'Pregledaj zadatak',
    'Remove user' => 'Ukloni korisnika',
    'Do you really want to remove this user: "%s"?' => 'Da li zaista želite da uklonite korisnika: "%s"?',
    'All users' => 'Svi korisnici',
    'Username' => 'Korisnik',
    'Password' => 'Lozinka',
    'Administrator' => 'Administrator',
    'Sign in' => 'Prijava',
    'Users' => 'Korisnici',
    'Forbidden' => 'Zabranjeno',
    'Access Forbidden' => 'Zabranjen pristup',
    'Edit user' => 'Izmeni korisnika',
    'Logout' => 'Odjava',
    'Bad username or password' => 'Loše korisničko ime ili lozinka',
    'Edit project' => 'Izmeni projekat',
    'Name' => 'Naziv',
    'Projects' => 'Projekti',
    'No project' => 'Bez projekta',
    'Project' => 'Projekat',
    'Status' => 'Status',
    'Tasks' => 'Zadatak',
    'Board' => 'Tabla',
    'Actions' => 'Akcije',
    'Inactive' => 'Neaktivno',
    'Active' => 'Aktivno',
    'Unable to update this board.' => 'Ažuriranje ove table nije uspelo',
    'Disable' => 'Onemogući',
    'Enable' => 'Omogući',
    'New project' => 'Novi projekat',
    'Do you really want to remove this project: "%s"?' => 'Da li zaista želite da uklonite projekat: "%s"?',
    'Remove project' => 'Ukloni projekat',
    'Edit the board for "%s"' => 'Izmeni tablu za "%s"',
    'Add a new column' => 'Dodaj novu kolonu',
    'Title' => 'Naslov',
    'Assigned to %s' => 'Dodeljen korisniku %s',
    'Remove a column' => 'Ukloni kolonu',
    'Unable to remove this column.' => 'Nije moguće ukloniti ovu kolonu.',
    'Do you really want to remove this column: "%s"?' => 'Da li zaista želite da uklonite ovu kolonu: "%s"?',
    'Settings' => 'Podešavanja',
    'Application settings' => 'Podešavanja aplikacije',
    'Language' => 'Jezik',
    'Webhook token:' => 'Webhook token :',
    'API token:' => 'API token',
    'Database size:' => 'Veličina baze :',
    'Download the database' => 'Preuzmi bazu',
    'Optimize the database' => 'Optimizuj bazu',
    '(VACUUM command)' => '(VACUUM komanda)',
    '(Gzip compressed Sqlite file)' => '(Sqlite baza spakovana Gzip-om)',
    'Close a task' => 'Zatvori zadatak',
    'Column' => 'Kolona',
    'Color' => 'Boja',
    'Assignee' => 'Izvršilac',
    'Create another task' => 'Dodaj zadatak',
    'New task' => 'Novi zadatak',
    'Open a task' => 'Otvori zadatak',
    'Do you really want to open this task: "%s"?' => 'Da li zaista želite da otvorite ovaj zadatak: "%s"?',
    'Back to the board' => 'Nazad na tablu',
    'There is nobody assigned' => 'Nikome nije dodeljeno',
    'Column on the board:' => 'Kolona na tabli:',
    'Close this task' => 'Zatvori ovaj zadatak',
    'Open this task' => 'Otvori ovaj zadatak',
    'There is no description.' => 'Bez opisa.',
    'Add a new task' => 'Dodaj zadatak',
    'The username is required' => 'Korisničko ime je obavezno',
    'The maximum length is %d characters' => 'Maksimalna dužina je %d znakova',
    'The minimum length is %d characters' => 'Minimalna dužina je %d znakova',
    'The password is required' => 'Lozinka je obavezna',
    'This value must be an integer' => 'Mora biti celobrojna vrednost',
    'The username must be unique' => 'Korisničko ime mora biti jedinstveno',
    'The user id is required' => 'ID korisnika je obavezan',
    'Passwords don\'t match' => 'Lozinke se ne podudaraju',
    'The confirmation is required' => 'Potvrda je obavezna',
    'The project is required' => 'Projekat je obavezan',
    'The id is required' => 'ID je obavezan',
    'The project id is required' => 'ID projekta je obavezan',
    'The project name is required' => 'Naziv projekta je obavezan',
    'The title is required' => 'Naslov je obavezan',
    'Settings saved successfully.' => 'Podešavanja uspešno snimljena.',
    'Unable to save your settings.' => 'Nije mogućue sačuvati podešavanja.',
    'Database optimization done.' => 'Optimizacija baze je završena.',
    'Your project has been created successfully.' => 'Projekat je uspešno napravljen.',
    'Unable to create your project.' => 'Nije mogućue kreirati projekat.',
    'Project updated successfully.' => 'Projekat je uspešno ažuriran.',
    'Unable to update this project.' => 'Nije mogućue ažurirati ovaj projekat.',
    'Unable to remove this project.' => 'Nije mogućue ukloniti ovaj projekat.',
    'Project removed successfully.' => 'Projekat uspešno uklonjen.',
    'Project activated successfully.' => 'Projekat uspešno aktiviran.',
    'Unable to activate this project.' => 'Nije mogućue aktivirti ovaj projekat.',
    'Project disabled successfully.' => 'Projekat uspešno deaktiviran.',
    'Unable to disable this project.' => 'Nije moguće onemogućiti ovaj projekat.',
    'Unable to open this task.' => 'Nije moguće otvoriti ovaj zadatak',
    'Task opened successfully.' => 'Zadatak uspešno otvoren.',
    'Unable to close this task.' => 'Nije moguće zatvoriti ovaj zadatak.',
    'Task closed successfully.' => 'Zadatak uspešno zatvoren.',
    'Unable to update your task.' => 'Nije moguće ažuriranje zadatka.',
    'Task updated successfully.' => 'Zadatak uspešno ažuriran.',
    'Unable to create your task.' => 'Nije moguće kreiranje zadatka.',
    'Task created successfully.' => 'Zadatak uspešno kreiran.',
    'User created successfully.' => 'Korisnik uspešno kreiran',
    'Unable to create your user.' => 'Nije uspelo kreiranje korisnika.',
    'User updated successfully.' => 'Korisnik uspešno ažuriran.',
    'User removed successfully.' => 'Korisnik uspešno uklonjen.',
    'Unable to remove this user.' => 'Nije moguće uklanjanje korisnika.',
    'Board updated successfully.' => 'Tabla uspešno ažurirana.',
    'Ready' => 'Spreman',
    'Backlog' => 'Log',
    'Work in progress' => 'U radu',
    'Done' => 'Gotovo',
    'Application version:' => 'Verzija aplikacije:',
    'Id' => 'Id',
    'Public link' => 'Javni link',
    'Timezone' => 'Vremenska zona',
    'Sorry, I didn\'t find this information in my database!' => 'Na žalost, nije pronađena informacija u bazi',
    'Page not found' => 'Strana nije pronađena',
    'Complexity' => 'Složenost',
    'Task limit' => 'Ograničenje zadatka',
    'Task count' => 'Broj zadataka',
    'User' => 'Korisnik',
    'Comments' => 'Komentari',
    'Comment is required' => 'Komentar je obavezan',
    'Comment added successfully.' => 'Komentar uspešno ostavljen',
    'Unable to create your comment.' => 'Nemoguće kreiranje komentara',
    'Due Date' => 'Rok završetka',
    'Invalid date' => 'Loš datum',
    'Automatic actions' => 'Automatske akcije',
    'Your automatic action has been created successfully.' => 'Uspešno kreirana automatska akcija',
    'Unable to create your automatic action.' => 'Nemoguće kreiranje automatske akcije',
    'Remove an action' => 'Obriši akciju',
    'Unable to remove this action.' => 'Nije moguće obrisati akciju',
    'Action removed successfully.' => 'Akcija obrisana',
    'Automatic actions for the project "%s"' => 'Akcije za automatizaciju projekta "%s"',
    'Add an action' => 'dodaj akciju',
    'Event name' => 'Naziv događaja',
    'Action' => 'Akcija',
    'Event' => 'Događaj',
    'When the selected event occurs execute the corresponding action.' => 'Kad se događaj desi izvrši odgovarajuću akciju',
    'Next step' => 'Sledeći korak',
    'Define action parameters' => 'Definiši parametre akcije',
    'Do you really want to remove this action: "%s"?' => 'Da li da obrišem akciju "%s"?',
    'Remove an automatic action' => 'Obriši automatsku akciju',
    'Assign the task to a specific user' => 'Dodeli zadatak određenom korisniku',
    'Assign the task to the person who does the action' => 'Dodeli zadatak korisniku koji je izvršio akciju',
    'Duplicate the task to another project' => 'Kopiraj akciju u drugi projekat',
    'Move a task to another column' => 'Premesti zadatak u drugu kolonu',
    'Task modification' => 'Izmena zadatka',
    'Task creation' => 'Kreiranje zadatka',
    'Closing a task' => 'Zatvaranja zadatka',
    'Assign a color to a specific user' => 'Dodeli boju korisniku',
    'Position' => 'Pozicija',
    'Duplicate to project' => 'Kopiraj u drugi projekat',
    'Duplicate' => 'Napravi kopiju',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Komentar uspešno ažuriran.',
    'Unable to update your comment.' => 'Neuspešno ažuriranje komentara.',
    'Remove a comment' => 'Obriši komentar',
    'Comment removed successfully.' => 'Komentar je uspešno obrisan.',
    'Unable to remove this comment.' => 'Neuspešno brisanje komentara.',
    'Do you really want to remove this comment?' => 'Da li da obrišem ovaj komentar?',
    'Current password for the user "%s"' => 'Trenutna lozinka za korisnika "%s"',
    'The current password is required' => 'Trenutna lozinka je obavezna',
    'Wrong password' => 'Pogrešna lozinka',
    'Unknown' => 'Nepoznat',
    'Last logins' => 'Poslednja prijava',
    'Login date' => 'Datum prijave',
    'Authentication method' => 'Metod autentifikacije',
    'IP address' => 'IP adresa',
    'User agent' => 'Pregledač',
    'Persistent connections' => 'Stalna konekcija',
    'No session.' => 'Bez sesije',
    'Expiration date' => 'Ističe',
    'Remember Me' => 'Zapamti me',
    'Creation date' => 'Datum kreiranja',
    'Everybody' => 'Svi',
    'Open' => 'Otvoreni',
    'Closed' => 'Zatvoreni',
    'Search' => 'Traži',
    'Nothing found.' => 'Ništa nije pronađeno',
    'Due date' => 'Rok završetka',
    'Description' => 'Opis',
    '%d comments' => '%d komentara',
    '%d comment' => '%d komentar',
    'Email address invalid' => 'Email adresa nije validna',
    'Your external account is not linked anymore to your profile.' => 'Vaš spoljni nalog više nije povezan sa vašim profilom.',
    'Unable to unlink your external account.' => 'Nije moguće prekinuti vezu sa spoljnim nalogom.',
    'External authentication failed' => 'Spoljna autentifikacija nije uspela',
    'Your external account is linked to your profile successfully.' => 'Vaš spoljni nalog je uspešno povezan sa vašim profilom.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Zadatak uspešno uklonjen.',
    'Unable to remove this task.' => 'Nije moguće ukoliniti zadatak.',
    'Remove a task' => 'Ukloni zadatak',
    'Do you really want to remove this task: "%s"?' => 'Da li zaista želite da uklonite ovaj zadatak "%s"?',
    'Assign automatically a color based on a category' => 'Automatski dodeli boju po kategoriji',
    'Assign automatically a category based on a color' => 'Automatski dodeli kategoriju po boji',
    'Task creation or modification' => 'Kreiranje ili izmena zadatka',
    'Category' => 'Kategorija',
    'Category:' => 'Kategorija:',
    'Categories' => 'Kategorije',
    'Your category has been created successfully.' => 'Uspešno kreirana kategorija.',
    'This category has been updated successfully.' => 'Kategorija je uspešno izmenjena',
    'Unable to update this category.' => 'Nije moguće izmeniti kategoriju',
    'Remove a category' => 'Obriši kategoriju',
    'Category removed successfully.' => 'Kategorija uspešno uklonjena.',
    'Unable to remove this category.' => 'Nije moguće ukloniti kategoriju.',
    'Category modification for the project "%s"' => 'Izmena kategorije za projekat "%s"',
    'Category Name' => 'Naziv kategorije',
    'Add a new category' => 'Dodaj novu kategoriju',
    'Do you really want to remove this category: "%s"?' => 'Da li zaista želiš da ukloniš kategoriju: "%s"?',
    'All categories' => 'Sve kategorije',
    'No category' => 'Bez kategorije',
    'The name is required' => 'Naziv je obavezan',
    'Remove a file' => 'Ukloni fajl',
    'Unable to remove this file.' => 'Fajl nije moguće ukloniti.',
    'File removed successfully.' => 'Uspešno uklonjen fajl.',
    'Attach a document' => 'Priloži dokument',
    'Do you really want to remove this file: "%s"?' => 'Da li zaista želite da ukolnite fajl: "%s"?',
    'Attachments' => 'Prilozi',
    'Edit the task' => 'Izmena zadatka',
    'Add a comment' => 'Dodaj komentar',
    'Edit a comment' => 'Izmeni komentar',
    'Summary' => 'Pregled',
    'Time tracking' => 'Praćenje vremena',
    'Estimate:' => 'Procena:',
    'Spent:' => 'Potrošeno:',
    'Do you really want to remove this sub-task?' => 'Da li zaista želite da uklonite podzadatak?',
    'Remaining:' => 'Preostalo:',
    'hours' => 'sati',
    'estimated' => 'procenjeno',
    'Sub-Tasks' => 'Podzadaci',
    'Add a sub-task' => 'Dodaj podzadatak',
    'Original estimate' => 'Originalna procena',
    'Create another sub-task' => 'Dodaj novi podzadatak',
    'Time spent' => 'Utrošeno vreme',
    'Edit a sub-task' => 'Izmeni podzadatak',
    'Remove a sub-task' => 'Ukloni podzadatak',
    'The time must be a numeric value' => 'Vreme mora biti numerička vrednost',
    'Todo' => 'Uraditi',
    'In progress' => 'U radu',
    'Sub-task removed successfully.' => 'Podzadatak uspešno uklonjen.',
    'Unable to remove this sub-task.' => 'Nie moguće ukloniti ovaj podzadatak',
    'Sub-task updated successfully.' => 'Podzadatak uspešno ažuriran',
    'Unable to update your sub-task.' => 'Ažuriranje podzadatka nije uspelo.',
    'Unable to create your sub-task.' => 'Nije moguće kreirati podzadatak.',
    'Maximum size: ' => 'Maksimalna veličina: ',
    'Display another project' => 'Prikaži drugi projekat',
    'Created by %s' => 'Napravio/la %s',
    'Tasks Export' => 'Izvoz zadataka',
    'Start Date' => 'Početni datum',
    'Execute' => 'Izvrši',
    'Task Id' => 'Identifikator zadatka',
    'Creator' => 'Autor',
    'Modification date' => 'Datum izmene',
    'Completion date' => 'Datum kompletiranja',
    'Clone' => 'Kloniraj',
    'Project cloned successfully.' => 'Projekat uspešno kloniran.',
    'Unable to clone this project.' => 'Nije moguće klonirati projekat.',
    'Enable email notifications' => 'Omogući obaveštenja email-om',
    'Task position:' => 'Pozicija zadatka:',
    'The task #%d has been opened.' => 'Zadatak #%d je otvoren.',
    'The task #%d has been closed.' => 'Zadatak #%d je zatvoren.',
    'Sub-task updated' => 'Podzadatak izmenjen',
    'Title:' => 'Naslov:',
    'Status:' => 'Status',
    'Assignee:' => 'Izvršilac:',
    'Time tracking:' => 'Praćenje vremena: ',
    'New sub-task' => 'Novi podzadatak',
    'New attachment added "%s"' => 'Novi prilog ubačen "%s"',
    'New comment posted by %s' => 'Novi komentar ostavio %s',
    'New comment' => 'Novi komentar',
    'Comment updated' => 'Komentar ažuriran',
    'New subtask' => 'Novi podzadatak',
    'I only want to receive notifications for these projects:' => 'Želim obaveštenja samo za projekate:',
    'view the task on Kanboard' => 'pregled zadataka u Kanboard-u',
    'Public access' => 'Javni pristup',
    'Disable public access' => 'Zabrani javni pristup',
    'Enable public access' => 'Dozvoli javni pristup',
    'Public access disabled' => 'Javni pristup onemogućen!',
    'Move the task to another project' => 'Premesti zadatak u drugi projekat',
    'Move to project' => 'Premesti u drugi projekat',
    'Do you really want to duplicate this task?' => 'Da li zaista želite da kopirate ovaj zadatak?',
    'Duplicate a task' => 'Kopiraj zadatak',
    'External accounts' => 'Spoljni nalozi',
    'Account type' => 'Tip naloga',
    'Local' => 'Lokalno',
    'Remote' => 'Udaljno',
    'Enabled' => 'Omogućeno',
    'Disabled' => 'Onemogućeno',
    'Login:' => 'Prijava:',
    'Full Name:' => 'Ime i prezime',
    'Email:' => 'Email: ',
    'Notifications:' => 'Obaveštenja: ',
    'Notifications' => 'Obaveštenja',
    'Account type:' => 'Vrsta naloga:',
    'Edit profile' => 'Izmeni profil',
    'Change password' => 'Izmeni lozinku',
    'Password modification' => 'Izmena lozinke',
    'External authentications' => 'Spoljne akcije',
    'Never connected.' => 'Nikad povezan.',
    'No external authentication enabled.' => 'Nema omogućenih spoljnih autentifikacija.',
    'Password modified successfully.' => 'Uspešna izmena lozinke.',
    'Unable to change the password.' => 'Nije moguće izmeniti lozinku.',
    'Change category' => 'Izmeni kategoriju',
    '%s updated the task %s' => '%s je ažurirao/la zadatak %s',
    '%s opened the task %s' => '%s je otvorio/la zadatak %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s je premestio/la zadatak %s na poziciju #%d u koloni "%s"',
    '%s moved the task %s to the column "%s"' => '%s je premestio/la zadatak %s u kolonu "%s"',
    '%s created the task %s' => '%s je kreirao/la zadatak %s',
    '%s closed the task %s' => '%s je zatvorio/la zadatak %s',
    '%s created a subtask for the task %s' => '%s je kreirao/la podzadatak za zadatka %s',
    '%s updated a subtask for the task %s' => '%s je izmenio/la podzadatak za zadatka %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Dodeljen korisniku %s uz procenu vremena %s/%sh',
    'Not assigned, estimate of %sh' => 'Nedodeljen, procenjeno vreme %sh',
    '%s updated a comment on the task %s' => '%s je ažurirao/la komentar za zadatka %s',
    '%s commented the task %s' => '%s je komentarisao/la zadatak %s',
    '%s\'s activity' => '%s - aktivnosti',
    'RSS feed' => 'RSS kanal',
    '%s updated a comment on the task #%d' => '%s ažurirao/la komentar za zadatka #%d',
    '%s commented on the task #%d' => '%s komentarisao/la zadatak #%d',
    '%s updated a subtask for the task #%d' => '%s ažurirao/la podzadatak za zadatka #%d',
    '%s created a subtask for the task #%d' => '%s kreirao/la podzadatak za zadatka #%d',
    '%s updated the task #%d' => '%s ažurirao/la zadatak #%d',
    '%s created the task #%d' => '%s kreirao/la zadatak #%d',
    '%s closed the task #%d' => '%s zatvorio/la zadatak #%d',
    '%s opened the task #%d' => '%s otvorio/la zadatak #%d',
    'Activity' => 'Aktivnosti',
    'Default values are "%s"' => 'Podrazumevane vrednosti su: "%s"',
    'Default columns for new projects (Comma-separated)' => 'Podrazumevane kolone za novi projekat (odvojeno zarezom)',
    'Task assignee change' => 'Promena izvršioca zadatka',
    '%s changed the assignee of the task #%d to %s' => '%s je promenio/la izvršioca zadataka #%d na %s',
    '%s changed the assignee of the task %s to %s' => '%s je promenio/la izvršioca zadatak %s na %s',
    'New password for the user "%s"' => 'Nova lozinka za korisnika "%s"',
    'Choose an event' => 'Izaberi događaj',
    'Create a task from an external provider' => 'Napravi zadatak preko posrednika',
    'Change the assignee based on an external username' => 'Promeni izvršioca bazirano na spoljnom korisničkom imenu',
    'Change the category based on an external label' => 'Promeni kategoriju bazirano na spoljnoj etiketi',
    'Reference' => 'Referenca',
    'Label' => 'Etikieta',
    'Database' => 'Baza',
    'About' => 'Informacje',
    'Database driver:' => 'Drajver baze podataka:',
    'Board settings' => 'Podešavanje table',
    'Webhook settings' => 'Webhook podešavanja',
    'Reset token' => 'Resetuj token',
    'API endpoint:' => 'Krajnja tačka API-a:',
    'Refresh interval for personal board' => 'Interval osvežavanja ličnih tabli',
    'Refresh interval for public board' => 'Interval osvežavanja javnih tabli',
    'Task highlight period' => 'Period naznačavanja zadatka',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Period (u sekundama) za koji se smatra da je bilo izmena na zadatku (0 je onemogućeno, 2 dana je podrazumevano)',
    'Frequency in second (60 seconds by default)' => 'Učestalost u sekundama (60 je podrazumevano)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Učestalost u sekundama (0 gasi ovu funkecionalnost, 10 je podrazumevano)',
    'Application URL' => 'URL adresa aplikacije',
    'Token regenerated.' => 'Token regenerisan',
    'Date format' => 'Format datuma',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO format je uvek prihvatljiv, primer: "%s", "%s"',
    'New personal project' => 'Novi lični projekat',
    'This project is personal' => 'Ovaj projekat je ličan',
    'Add' => 'Dodaj',
    'Start date' => 'Datum početka',
    'Time estimated' => 'Procenjeno vreme',
    'There is nothing assigned to you.' => 'Ništa Vam nije dodeljeno',
    'My tasks' => 'Moji zadaci',
    'Activity stream' => 'Spisak aktinosti',
    'Dashboard' => 'Komandna tabla',
    'Confirmation' => 'Potvrda',
    'Webhooks' => 'Webhook-ovi',
    'API' => 'API',
    'Create a comment from an external provider' => 'Napravi komentar putem spoljnog posrednika',
    'Project management' => 'Uređivanje projekata',
    'Columns' => 'Kolone',
    'Task' => 'Zadatak',
    'Percentage' => 'Procenat',
    'Number of tasks' => 'Broj zadataka',
    'Task distribution' => 'Podela zadataka',
    'Analytics' => 'Analiza',
    'Subtask' => 'Podzadatak',
    'User repartition' => 'Zaduženja korisnika',
    'Clone this project' => 'Kloniraj projekat',
    'Column removed successfully.' => 'Kolona usepšno uklonjena.',
    'Not enough data to show the graph.' => 'Nedovoljno podataka za grafikon.',
    'Previous' => 'Prethodni',
    'The id must be an integer' => 'ID mora biti celobrojna vrednost',
    'The project id must be an integer' => 'ID projekta mora biti celobrojna vrednost',
    'The status must be an integer' => 'Status mora biti celobrojna vrednost',
    'The subtask id is required' => 'ID podzadataka je obavezan',
    'The subtask id must be an integer' => 'ID podzadatka mora biti celobrojna vrednost',
    'The task id is required' => 'ID zadatka je obavezan',
    'The task id must be an integer' => 'ID zadatka mora biti celobrojna vrednost',
    'The user id must be an integer' => 'ID korisnika mora biti celobrojna vrednost',
    'This value is required' => 'Ova vrednost je obavezna',
    'This value must be numeric' => 'Ova vrednost mora biti broj',
    'Unable to create this task.' => 'Nije moguće kreirati ovaj zadatak.',
    'Cumulative flow diagram' => 'Kumulativni dijagram toka',
    'Daily project summary' => 'Zbirni pregled po danima',
    'Daily project summary export' => 'Izvoz zbirnog pregleda po danima',
    'Exports' => 'Izvozi',
    'This export contains the number of tasks per column grouped per day.' => 'Ovaj izvoz sadrži broj zadataka po koloni grupisano po danima.',
    'Active swimlanes' => 'Aktivna staza',
    'Add a new swimlane' => 'Dodaj novu stazu',
    'Default swimlane' => 'Podrazumevana staza',
    'Do you really want to remove this swimlane: "%s"?' => 'Da li zasita želite da da uklonite stazu: "%s"?',
    'Inactive swimlanes' => 'Neaktivne staze',
    'Remove a swimlane' => 'Ukloni stazu',
    'Swimlane modification for the project "%s"' => 'Izmena staze za projekat "%s"',
    'Swimlane removed successfully.' => 'Staza uspešno uklonjen.',
    'Swimlanes' => 'Staze',
    'Swimlane updated successfully.' => 'Staza uspešno ažuriran.',
    'Unable to remove this swimlane.' => 'Nije moguće ukloniti ovu stazu',
    'Unable to update this swimlane.' => 'Nije moguće ažuriranje ove staze',
    'Your swimlane has been created successfully.' => 'Vaša staza je uspešno napravljena.',
    'Example: "Bug, Feature Request, Improvement"' => 'Na primer: "Greška, Zahtev za funkcionalnost, Poboljšanje"',
    'Default categories for new projects (Comma-separated)' => 'Podrazumevane kategorije za nove projekate',
    'Integrations' => 'Integracje',
    'Integration with third-party services' => 'Integracja sa uslugama spoljnih servisa',
    'Subtask Id' => 'ID podzadatka',
    'Subtasks' => 'Podzadaci',
    'Subtasks Export' => 'Izvoz podzdataka',
    'Task Title' => 'Naslov zadatka',
    'Untitled' => 'Bez naslova',
    'Application default' => 'Aplikacijski podrazumevano',
    'Language:' => 'Jezik:',
    'Timezone:' => 'Vremenska zona:',
    'All columns' => 'Sve kolone',
    'Next' => 'Sledeće',
    '#%d' => '#%d',
    'All swimlanes' => 'Sve staze',
    'All colors' => 'Sve boje',
    'Moved to column %s' => 'Premešten u kolonu %s',
    'User dashboard' => 'Korisnička komandna tabla',
    'Allow only one subtask in progress at the same time for a user' => 'Dozvoli samo jedan podzadatak "u radu" po korisniku',
    'Edit column "%s"' => 'Uredi kolonu "%s"',
    'Select the new status of the subtask: "%s"' => 'Izaberi novi status za podzadatak: "%s"',
    'Subtask timesheet' => 'Tabela vremena za podzadatke',
    'There is nothing to show.' => 'Nema podataka',
    'Time Tracking' => 'Praćenje vremena',
    'You already have one subtask in progress' => 'Već imate jedan podzadatak "u radu"',
    'Which parts of the project do you want to duplicate?' => 'Koje delove projekta želite da duplirate',
    'Disallow login form' => 'Zabrani prijavnu formu',
    'Start' => 'Početak',
    'End' => 'Kraj',
    'Task age in days' => 'Starost zadatka u danima',
    'Days in this column' => 'Dana u ovoj  koloni',
    '%dd' => '%dd',
    'Add a new link' => 'Dodaj novu vezu',
    'Do you really want to remove this link: "%s"?' => 'Da li zaista želite da uklonite ovu vezu: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Da li zaista želite da uklonite ovu vezu sa zadatkom #%d?',
    'Field required' => 'Polje je obavezno',
    'Link added successfully.' => 'Veza je uspešno dodata.',
    'Link updated successfully.' => 'Veza je uspešno ažurirana.',
    'Link removed successfully.' => 'Veza je uspešno uklonjena.',
    'Link labels' => 'Veza etiketa',
    'Link modification' => 'Veza modifikacija',
    'Opposite label' => 'Suprotna etiketa',
    'Remove a link' => 'Ukloni vezu',
    'The labels must be different' => 'Etikete moraju biti različite',
    'There is no link.' => 'Ne postoji veza',
    'This label must be unique' => 'Ova etiketa mora biti jedinstvena',
    'Unable to create your link.' => 'Nije moguće napraviti vezu.',
    'Unable to update your link.' => 'Nije moguće ažurirati vezu.',
    'Unable to remove this link.' => 'Nije moguće ukloniti vezu.',
    'relates to' => 'relacija sa',
    'blocks' => 'blokira',
    'is blocked by' => 'je blokiran od',
    'duplicates' => 'duplira',
    'is duplicated by' => 'je dupliran od',
    'is a child of' => 'je dete od',
    'is a parent of' => 'je roditelj od',
    'targets milestone' => 'cilj prekretnice',
    'is a milestone of' => 'je od prekretnice',
    'fixes' => 'popravlja',
    'is fixed by' => 'je popravljen od',
    'This task' => 'Ovaj zadatak',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Proširi zadatke',
    'Collapse tasks' => 'Skupi zadatke',
    'Expand/collapse tasks' => 'Proširi/skupi zadatke',
    'Close dialog box' => 'Skupi dijalog',
    'Submit a form' => 'Pošalji obrazac',
    'Board view' => 'Pregled table',
    'Keyboard shortcuts' => 'Prečice tastature',
    'Open board switcher' => 'Otvori prekidače table',
    'Application' => 'Aplikacija',
    'Compact view' => 'Kompaktan pregled',
    'Horizontal scrolling' => 'Horizontalno listanje',
    'Compact/wide view' => 'Skupi/raširi pregled',
    'Currency' => 'Valuta',
    'Personal project' => 'Lični projekat',
    'AUD - Australian Dollar' => 'AUD - Australijski dolar',
    'CAD - Canadian Dollar' => 'CAD - Kanadski dolar',
    'CHF - Swiss Francs' => 'CHF - Švajcarski franak',
    'Custom Stylesheet' => 'Prilagođeni stil',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britanska funta',
    'INR - Indian Rupee' => 'INR - Indijski rupi',
    'JPY - Japanese Yen' => 'JPY - Japanski jen',
    'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => 'RSD - Srpski dinar',
    'CNY - Chinese Yuan' => 'CNY - Kineski jen',
    'USD - US Dollar' => 'USD - Američki dolar',
    'VES - Venezuelan Bolívar' => 'VES - Venecuelanski bolivar',
    'Destination column' => 'Odredišna kolona',
    'Move the task to another column when assigned to a user' => 'Premesti zadatak u neku drugu kolonu kada se dodeli izvršiocu',
    'Move the task to another column when assignee is cleared' => 'Premesti zadatak u neku drugu kolonu kada se ukloni izvršiocu',
    'Source column' => 'Izvorna kolona',
    'Transitions' => 'Prelaz',
    'Executer' => 'Izvršilac',
    'Time spent in the column' => 'Vreme provedeno u koloni',
    'Task transitions' => 'Prelazi zadatka',
    'Task transitions export' => 'Izvezi prelaze zadatka',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Ovaj izveštaj sadrži sva premeštanja unutar kolona za svaki zadatak sa datumom, korisnika i utrošeno vreme za svaki premeštaj.',
    'Currency rates' => 'Stopa valute',
    'Rate' => 'Stopa',
    'Change reference currency' => 'Promeni referentnu valutu',
    'Reference currency' => 'Referentna valuta',
    'The currency rate has been added successfully.' => 'Stopa valute je uspešno dodata.',
    'Unable to add this currency rate.' => 'Nije moguće dodati  ovu stopu valute.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s je uklonio/la izvršioca zadatka %s',
    'Information' => 'Informacije',
    'Check two factor authentication code' => 'Proverite kod za dvofaktorsku autentifikaciju',
    'The two factor authentication code is not valid.' => 'Kod dvofaktorsku autentifikaciju nije važeći.',
    'The two factor authentication code is valid.' => 'Kod za dvofaktorsku autentifikaciju je važeći',
    'Code' => 'Kod',
    'Two factor authentication' => 'Dvofaktorska autentifikacija',
    'This QR code contains the key URI: ' => 'Ovaj QR kod sadrži ključni URL:',
    'Check my code' => 'Proveri moj kod',
    'Secret key: ' => 'Tajni ključ: ',
    'Test your device' => 'Testiraj svoj uređaj',
    'Assign a color when the task is moved to a specific column' => 'Dodeli boju kada je zadatak pomeren u odabranu kolonu',
    '%s via Kanboard' => '%s putem Kanboard-a',
    'Burndown chart' => 'Preostalo posla / vreme',
    'This chart show the task complexity over the time (Work Remaining).' => 'Ovaj grafikon pokazuje kompleksnost zadatka tokom vremena (Preostalo posla)',
    'Screenshot taken %s' => 'Slika ekrana uzeta %s',
    'Add a screenshot' => 'Dodaj sliku ekrana',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Uzmi sliku ekrana i pritisni CTRL+V ili ⌘+V da zalepiš ovde.',
    'Screenshot uploaded successfully.' => 'Slika ekrana uspešno dodata.',
    'SEK - Swedish Krona' => 'SEK - Švedska kruna',
    'Identifier' => 'Identifikator',
    'Disable two factor authentication' => 'Onemogućite dvofaktorsku autnetifikaciju',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Da li zaista želite da onemogućite dvofaktorsku autentifikaciju za ovog korisnika: "%s"?',
    'Edit link' => 'Uredi vezu',
    'Start to type task title...' => 'Počni pisanje naslova zadatka...',
    'A task cannot be linked to itself' => 'Zadatak ne može biti povezan sa samim sobom',
    'The exact same link already exists' => 'Identična veza već postoji',
    'Recurrent task is scheduled to be generated' => 'Ponavljajući zadatak je pripremljen da bude kreiran',
    'Score' => 'Ocena',
    'The identifier must be unique' => 'Identifikator mora biti jedinstven',
    'This linked task id doesn\'t exists' => 'Povezani ID zadatka ne postoji',
    'This value must be alphanumeric' => 'Ova vrednost mora biti alfanumerička',
    'Edit recurrence' => 'Izmena ponavljanja',
    'Generate recurrent task' => 'Napravi ponavljajući zadatak',
    'Trigger to generate recurrent task' => 'Okidač koji pravi ponavljajući zadatak',
    'Factor to calculate new due date' => 'Faktor za računanje novog roka završetka',
    'Timeframe to calculate new due date' => 'Vremenski okvir za računanje novog roka završetka',
    'Base date to calculate new due date' => 'Početni datum za računanje novog roka završetka',
    'Action date' => 'Datum akcije',
    'Base date to calculate new due date: ' => 'Početni datum za računanje novog roka završetka: ',
    'This task has created this child task: ' => 'Ovaj zadatak je napravio dete zadatka: ',
    'Day(s)' => 'Dan/i',
    'Existing due date' => 'Postojeći rok završetka',
    'Factor to calculate new due date: ' => 'Faktor za računanje novog roka završetka: ',
    'Month(s)' => 'Mesec(i)',
    'This task has been created by: ' => 'Ovaj zadatak je napravio: ',
    'Recurrent task has been generated:' => 'Ponavljajući zadatak je napravio:',
    'Timeframe to calculate new due date: ' => 'Vremenski okvir za računanje novog roka završetka:',
    'Trigger to generate recurrent task: ' => 'Okidač za pravljenje ponavljajućeg zadatka',
    'When task is closed' => 'Kada je zadatak zatvoren',
    'When task is moved from first column' => 'Kada je zadatak premešten iz prve kolone',
    'When task is moved to last column' => 'Kada je zadatak premešten u poslednju kolonu',
    'Year(s)' => 'Godina/e',
    'Project settings' => 'Postavke projekta',
    'Automatically update the start date' => 'Automatski ažuriraj početni datum',
    'iCal feed' => 'iCal kanal',
    'Preferences' => 'Postavke',
    'Security' => 'Sigurnost',
    'Two factor authentication disabled' => 'Dvofaktorska autentifikacija je onemogućena',
    'Two factor authentication enabled' => 'Dvofaktorska autentifikacija je omogućena',
    'Unable to update this user.' => 'Nije moguće ažurirati ovog korisnika',
    'There is no user management for personal projects.' => 'Nema mehanizma za upravljanje korisnicima kod ličnih projekata.',
    'User that will receive the email' => 'Korisnik koji će primiti email',
    'Email subject' => 'Predmet email-a',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Dodaj komentar u dnevnik kada se zadatak premesti iz jedne kolonu u drugu',
    'Move the task to another column when the category is changed' => 'Pomeri zadatak u drugu kolonu kada je kategorija promenjena',
    'Send a task by email to someone' => 'Pošalji zadatak nekome putem email-a',
    'Reopen a task' => 'Ponovo otvori zadatak',
    'Notification' => 'Obaveštenja',
    '%s moved the task #%d to the first swimlane' => '%s je premestio/la zadatak #%d u prvu stazu',
    'Swimlane' => 'Staza',
    '%s moved the task %s to the first swimlane' => '%s je premestio/la zadatak %s u prvu stazu',
    '%s moved the task %s to the swimlane "%s"' => '%s je premestio/la zadatak %s u stazu "%s"',
    'This report contains all subtasks information for the given date range.' => 'Ovaj izveštaj sadrži sve informacije o podzadacima u datom periodu',
    'This report contains all tasks information for the given date range.' => 'Ovaj izveštaj sadrži sve informacije o zadacima u datom periodu',
    'Project activities for %s' => 'Aktivnosti projekta za %s',
    'view the board on Kanboard' => 'pregled table na Kanboard-u',
    'The task has been moved to the first swimlane' => 'Zadatak je premešten u prvu stazu',
    'The task has been moved to another swimlane:' => 'Zadatak je premešten u drugu stazu:',
    'New title: %s' => 'Novi naslov: %s',
    'The task is not assigned anymore' => 'Ovaj zadatak više nema izvršioca',
    'New assignee: %s' => 'Novi izvršilac: %s',
    'There is no category now' => 'Sada nema kategorije',
    'New category: %s' => 'Nova kategorija: %s',
    'New color: %s' => 'Nova boja: %s',
    'New complexity: %d' => 'Nova složenost: %d',
    'The due date has been removed' => 'Rok završetka je ukloljen',
    'There is no description anymore' => 'Nema više opisa',
    'Recurrence settings has been modified' => 'Promenjene postavke za ponavljajuće zadatke',
    'Time spent changed: %sh' => 'Utrošeno vreme je promenjeno: %sh',
    'Time estimated changed: %sh' => 'Očekivano vreme je promenjeno: %sh',
    'The field "%s" has been updated' => 'Polje "%s" je ažurirano',
    'The description has been modified:' => 'Promenjen opis:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Da li zaista želite da zatvorite zadatak "%s" kao i sve podzadatke?',
    'I want to receive notifications for:' => 'Želim da dobijam obaveštenja za:',
    'All tasks' => 'Sve zadatke',
    'Only for tasks assigned to me' => 'Samo za zadatke na kojima sam ja izvršilac',
    'Only for tasks created by me' => 'Samo za zadatke koje sam ja napravio/la',
    'Only for tasks created by me and tasks assigned to me' => 'Samo za zadatke koje sam ja napravio/la ili sam izvršilac zadatka',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Ukupno za sve kolone',
    'You need at least 2 days of data to show the chart.' => 'Da bi se prikazao ovaj grafik neophodno je da postoje podaci barem dva dana unazad.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Zaustavi tajmer',
    'Start timer' => 'Pokreni tajmer',
    'My activity stream' => 'Tok mojih aktivnosti',
    'Search tasks' => 'Pretraga zadataka',
    'Reset filters' => 'Resetuj filtere',
    'My tasks due tomorrow' => 'Moji zadaci koje treba završiti sutra',
    'Tasks due today' => 'Zadaci koje treba završiti danas',
    'Tasks due tomorrow' => 'Zadaci koje treba završiti sutra',
    'Tasks due yesterday' => 'Zadaci koje je trebalo završiti juče',
    'Closed tasks' => 'Zatvoreni zadaci',
    'Open tasks' => 'Otvoreni zadaci',
    'Not assigned' => 'Bez izvršioca',
    'View advanced search syntax' => 'Vidi naprednu sintaksu pretrage',
    'Overview' => 'Pregled',
    'Board/Calendar/List view' => 'Pregled Table/Kalendara/Liste',
    'Switch to the board view' => 'Prebacivanje na prikaz table',
    'Switch to the list view' => 'Prebacivanje na prikaz liste',
    'Go to the search/filter box' => 'Idite na polje za pretragu / filter',
    'There is no activity yet.' => 'Nema aktivnosti još uvek.',
    'No tasks found.' => 'Zadaci nisu pronađeni.',
    'Keyboard shortcut: "%s"' => 'Prečica tastature: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filter',
    'Advanced search' => 'Napredna pretraga',
    'Example of query: ' => 'Primer za upit: ',
    'Search by project: ' => 'Pretraga po projektu: ',
    'Search by column: ' => 'Pretraga po koloni: ',
    'Search by assignee: ' => 'Pretraga po izvršiocu: ',
    'Search by color: ' => 'Pretraga po boji: ',
    'Search by category: ' => 'Pretraga po kategoriji: ',
    'Search by description: ' => 'Pretraga po opisu: ',
    'Search by due date: ' => 'Pretraga po roku završetka: ',
    'Average time spent in each column' => 'Prosek utrošenog vrmena u svakoj koloni',
    'Average time spent' => 'Prosek utrošenog vremena',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Ovaj grafikon pokazuje prosek utrošenog vremena u svakoj koloni za posljednjih %d zadataka.',
    'Average Lead and Cycle time' => 'Prosečno vreme realizacije(lead) i izvođenja(cycle)',
    'Average lead time: ' => 'Prosečno vreme realizacije: ',
    'Average cycle time: ' => 'Prosečno vreme ciklusa: ',
    'Cycle Time' => 'Vreme ciklusa',
    'Lead Time' => 'Vreme realizacije',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Ovaj grafikon prikazuje prosečno vreme realizacije i ciklusa za posljednjih %d zadataka tokom vremena.',
    'Average time into each column' => 'Prosečno vreme u svakoj koloni',
    'Lead and cycle time' => 'Vreme realizacije i ciklusa',
    'Lead time: ' => 'Vreme realizacije: ',
    'Cycle time: ' => 'Vreme ciklusa: ',
    'Time spent in each column' => 'Utrošeno vreme u svakoj koloni',
    'The lead time is the duration between the task creation and the completion.' => 'Vreme realizacije je vreme koje je proteklo između otvaranja i zatvaranja zadatka.',
    'The cycle time is the duration between the start date and the completion.' => 'Vreme ciklusa je vreme koje je proteklo između početka i završetka rada na zadatku.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Ako zadatak nije zatvoren trenutno vreme se koristi umesto datuma završetka.',
    'Set the start date automatically' => 'Automatski postavi početno vreme',
    'Edit Authentication' => 'Uredi autentifikaciju',
    'Remote user' => 'Udaljeni korisnik',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Udaljeni korisnik ne čuva lozinku u Kanboard bazi, npr: LDAP, Google i Github korisnički nalozi.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Ako ste štiklirali polje "Zabrani prijavnu formu" unos pristupnih podataka u prijavnoj formi će biti ignorisan.',
    'Default task color' => 'Podrazumijevana boja zadatka',
    'This feature does not work with all browsers.' => 'Ova funckionalnost ne radi na svim pregledačima.',
    'There is no destination project available.' => 'Nije dostupan nijedan odredišni projekat.',
    'Trigger automatically subtask time tracking' => 'Okidač za automatsko vremensko praćenje za podzadatke',
    'Include closed tasks in the cumulative flow diagram' => 'Obuhvati zatvorene zadatke u kumulativnom dijagramu toka',
    'Current swimlane: %s' => 'Trenutna staza: %s',
    'Current column: %s' => 'Trenutna kolona: %s',
    'Current category: %s' => 'Trenutna kategorija: %s',
    'no category' => 'bez kategorije',
    'Current assignee: %s' => 'Trenutni izvršilac: %s',
    'not assigned' => 'nije dodeljeno',
    'Author:' => 'Autor:',
    'contributors' => 'saradnici',
    'License:' => 'Licenca:',
    'License' => 'Licenca',
    'Enter the text below' => 'Unesite tekst ispod',
    'Start date:' => 'Početno vreme:',
    'Due date:' => 'Rok završetka:',
    'People who are project managers' => 'Osobe koji su menadžeri projekta',
    'People who are project members' => 'Osobe koje su članovi projekta',
    'NOK - Norwegian Krone' => 'NOK - Norveška kruna',
    'Show this column' => 'Prikaži ovu kolonu',
    'Hide this column' => 'Sakrij ovu kolonu',
    'End date' => 'Datum završetka',
    'Users overview' => 'Pregled korisnika',
    'Members' => 'Članovi',
    'Shared project' => 'Deljeni projekat',
    'Project managers' => 'Menadžeri projekta',
    'Projects list' => 'Lista projekata',
    'End date:' => 'Datum završetka:',
    'Change task color when using a specific task link' => 'Promeni boju zadatka kada se koristi određena veza na zadatku',
    'Task link creation or modification' => 'Veza na zadatku je napravljena ili izmenjena',
    'Milestone' => 'Prekretnica',
    'Reset the search/filter box' => 'Resetuj plje za pretragu/filtere',
    'Documentation' => 'Dokumentacija',
    'Author' => 'Autor',
    'Version' => 'Verzija',
    'Plugins' => 'Dodaci',
    'There is no plugin loaded.' => 'Nema učitanih dodataka.',
    'My notifications' => 'Moja obaveštenja',
    'Custom filters' => 'Prilagođeni filteri',
    'Your custom filter has been created successfully.' => 'Tvoj prilagođeni filter je uspešno napravljen.',
    'Unable to create your custom filter.' => 'Nije moguće napraviti prilagođeni filter.',
    'Custom filter removed successfully.' => 'Prilagođeni filter uspešno uklonjen.',
    'Unable to remove this custom filter.' => 'Nije moguće ukloniti prilagođeni filter.',
    'Edit custom filter' => 'Uredi prilagođeni filter',
    'Your custom filter has been updated successfully.' => 'Prilagođeni filter uspešno ažuriran.',
    'Unable to update custom filter.' => 'Nije moguće ažurirati prilagođeni filter',
    'Web' => 'Veb',
    'New attachment on task #%d: %s' => 'Novi priložak na zadatku #%d: %s',
    'New comment on task #%d' => 'Novi komentar na zadatku #%d',
    'Comment updated on task #%d' => 'Ažuriran komentar na zadatku #%d',
    'New subtask on task #%d' => 'Novi podzadatak na zadatku #%d',
    'Subtask updated on task #%d' => 'Podzadatak ažuriran na zadatku #%d',
    'New task #%d: %s' => 'Novi zadatak #%d: %s',
    'Task updated #%d' => 'Zadatak ažuriran #%d',
    'Task #%d closed' => 'Zadatak #%d zatvoren',
    'Task #%d opened' => 'Zadatak #%d otvoren',
    'Column changed for task #%d' => 'Promenjena kolona za zadatak #%d',
    'New position for task #%d' => 'Nova pozicija za zadatak #%d',
    'Swimlane changed for task #%d' => 'Staza je promenjena za zadatak #%d',
    'Assignee changed on task #%d' => 'Izvršilac je promenjen na zadatku #%d',
    '%d overdue tasks' => '%d zadataka kasni',
    'Task #%d is overdue' => 'Zadatak #%d kasni',
    'No notification.' => 'Nema novih obaveštenja.',
    'Mark all as read' => 'Označi sve kao pročitano',
    'Mark as read' => 'Označi kao pročitano',
    'Total number of tasks in this column across all swimlanes' => 'Ukupan broj zadataka u ovoj koloni u svim stazama',
    'Collapse swimlane' => 'Skupi stazu',
    'Expand swimlane' => 'Proširi stazu',
    'Add a new filter' => 'Dodaj novi filter',
    'Share with all project members' => 'Podeli sa svim članovima projekta',
    'Shared' => 'Podeljeno',
    'Owner' => 'Vlasnik',
    'Unread notifications' => 'Nepročitana obaveštenja',
    'Notification methods:' => 'Metode obaveštenja:',
    'Unable to read your file' => 'Nije moguće pročitati datoteku',
    '%d task(s) have been imported successfully.' => '%d zadataka uspešno uvezeno.',
    'Nothing has been imported!' => 'Ništa nije uvezeno!',
    'Import users from CSV file' => 'Uvezi korisnike putem CSV datoteke',
    '%d user(s) have been imported successfully.' => '%d korisnika uspešno uvezeno.',
    'Comma' => 'Zarez',
    'Semi-colon' => 'Tačka i zarez',
    'Tab' => 'Tab',
    'Vertical bar' => 'Vertikalna traka',
    'Double Quote' => 'Dvostruki navodnici',
    'Single Quote' => 'Jednostruki navodnici',
    '%s attached a file to the task #%d' => '%s je dodao/la novu datoteku u zadatak %d',
    'There is no column or swimlane activated in your project!' => 'Nema kolone ili aktivne staze u Vašem projektu!',
    'Append filter (instead of replacement)' => 'Dodaj filter (umesto zamene postojećeg)',
    'Append/Replace' => 'Dodaj/Zameni',
    'Append' => 'Dodaj',
    'Replace' => 'Zameni',
    'Import' => 'Uvoz',
    'Change sorting' => 'Promeni sortiranje',
    'Tasks Importation' => 'Uvoz zadataka',
    'Delimiter' => 'Delimter',
    'Enclosure' => 'Prilog',
    'CSV File' => 'CSV datoteka',
    'Instructions' => 'Uputstva',
    'Your file must use the predefined CSV format' => 'Vaša datoteka mora koristiti predefinisani CSV format',
    'Your file must be encoded in UTF-8' => 'Vaša datoteka mora koristiti UTF-8 enkodovana',
    'The first row must be the header' => 'Prvi red mora biti zaglavlje',
    'Duplicates are not verified for you' => 'Dupliranja neće biti provervana (morate sami uraditi)',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Rok završetka mora biti u ISO formatu: YYYY-MM-DD',
    'Download CSV template' => 'Preuzmi CSV šablon',
    'No external integration registered.' => 'Nema registrovanih spoljnih integracija.',
    'Duplicates are not imported' => 'Duplikati nisu uveženi',
    'Usernames must be lowercase and unique' => 'Korisnička imena moraju biti napisana malim slovima i jedinstvena',
    'Passwords will be encrypted if present' => 'Lozinke (ako postoje) će biti šiforvane',
    '%s attached a new file to the task %s' => '%s je dodao/la novu datoteku u zadatak %s',
    'Link type' => 'Tip veze',
    'Assign automatically a category based on a link' => 'Automatsko dodeljivanje kategorije bazirano na vezi',
    'BAM - Konvertible Mark' => 'BAM - Konvertibilna marka',
    'Assignee Username' => 'Korisničko ime izvršioca',
    'Assignee Name' => 'Ime izvršioca',
    'Groups' => 'Grupe',
    'Members of %s' => 'Članovi %s',
    'New group' => 'Nova grupa',
    'Group created successfully.' => 'Grupa uspešno kreirana.',
    'Unable to create your group.' => 'Nije moguće kreirati grupu.',
    'Edit group' => 'Uredi grupu',
    'Group updated successfully.' => 'Grupa uspešno ažurirana.',
    'Unable to update your group.' => 'Nije moguće ažurirati grupu',
    'Add group member to "%s"' => 'Dodaj člana u grupu "%s"',
    'Group member added successfully.' => 'Uspješno dodat član grupe.',
    'Unable to add group member.' => 'Nije moguće dodati člana grupi.',
    'Remove user from group "%s"' => 'Ukloni korisnika iz grupe "%s"',
    'User removed successfully from this group.' => 'Korisnik uspešno uklonjen iz grupe.',
    'Unable to remove this user from the group.' => 'Nije moguće ukloniti korisnika iz grupe.',
    'Remove group' => 'Ukloni grupu',
    'Group removed successfully.' => 'Grupa uspešno uklonjena.',
    'Unable to remove this group.' => 'Nije moguće ukloniti grupu.',
    'Project Permissions' => 'Dozvole na projektu',
    'Manager' => 'Menadžer',
    'Project Manager' => 'Menadžer projekta',
    'Project Member' => 'Član projekta',
    'Project Viewer' => 'Posmatrač projekta',
    'Your account is locked for %d minutes' => 'Tvoj korisnički nalog je zaključan narednih %d minuta',
    'Invalid captcha' => 'Pogrešan captcha',
    'The name must be unique' => 'Ime mora biti jedinstveno',
    'View all groups' => 'Pregledaj sve grupe',
    'There is no user available.' => 'Nema dostupnih korisnika.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Da li zaista želite da uklonite korisnika "%s" iz grupe "%s"?',
    'There is no group.' => 'Nema grupe',
    'Add group member' => 'Dodaj člana grupe',
    'Do you really want to remove this group: "%s"?' => 'Da li zaista želite da ukloniti ovu grupu: "%s"?',
    'There is no user in this group.' => 'Trenutno nema korisnika u grupi.',
    'Permissions' => 'Dozvole',
    'Allowed Users' => 'Dozvoljeni korisnici',
    'No specific user has been allowed.' => 'Nijednom specifiičnom korisniku nije dozvoljeno.',
    'Role' => 'Uloge',
    'Enter user name...' => 'Unesi korisničko ime...',
    'Allowed Groups' => 'Dozvoljene grupe',
    'No group has been allowed.' => 'Nijednoj grupi nije dozvoljeno.',
    'Group' => 'Grupa',
    'Group Name' => 'Ime grupe',
    'Enter group name...' => 'Unesi ime grupe...',
    'Role:' => 'Uloga:',
    'Project members' => 'Članovi projekta',
    '%s mentioned you in the task #%d' => '%s Vas je spomenuo/la u zadatku #%d',
    '%s mentioned you in a comment on the task #%d' => '%s Vas je spomenuo/la u komentaru zadatka #%d',
    'You were mentioned in the task #%d' => 'Spomenuti ste u zadatku #%d',
    'You were mentioned in a comment on the task #%d' => 'Spomenuti ste u komentaru zadatka #%d',
    'Estimated hours: ' => 'Procenjeno sati:',
    'Actual hours: ' => 'Stvarno sati:',
    'Hours Spent' => 'Utrošeno sati:',
    'Hours Estimated' => 'Sati procenjeno',
    'Estimated Time' => 'Procenjeno vreme',
    'Actual Time' => 'Stvarno vreme',
    'Estimated vs actual time' => 'Procenjeno / stvarno vreme',
    'RUB - Russian Ruble' => 'RUB - Ruski rubij',
    'Assign the task to the person who does the action when the column is changed' => 'Dodeli zadatak osobi koja izvrši akciju promene kolone',
    'Close a task in a specific column' => 'Zatvori zadatak u određenoj koloni',
    'Time-based One-time Password Algorithm' => 'Algoritam jednokratne lozinke zasnovan na vremenu',
    'Two-Factor Provider: ' => 'Dvofaktorski dobavljač:',
    'Disable two-factor authentication' => 'Onemogući dvofaktorsku autentifikaciju',
    'Enable two-factor authentication' => 'Omogućite dvofaktorsku autentifikaciju',
    'There is no integration registered at the moment.' => 'Trenutno nije registrovana nijedna integracija.',
    'Password Reset for Kanboard' => 'Promena lozinke za Kanboard',
    'Forgot password?' => 'Zaboravljena lozinka?',
    'Enable "Forget Password"' => 'Omogući "Zaboravljena lozinka"',
    'Password Reset' => 'Promena lozinke',
    'New password' => 'Nova lozinka',
    'Change Password' => 'Promeni lozinku',
    'To reset your password click on this link:' => 'Da biste promenili lozinku kliknite na ovaj link:',
    'Last Password Reset' => 'Posljednja promena lozinke',
    'The password has never been reinitialized.' => 'Lozinka nije nikada menjana.',
    'Creation' => 'Napravljena',
    'Expiration' => 'Ističe',
    'Password reset history' => 'Istorija promena lozinki',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Svi zadaci kolone "%s" i staze "%s" uspešno su zatvoreni.',
    'Do you really want to close all tasks of this column?' => 'Da li zaista želite da zatvorite sve zadatke ove kolone?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadatak/zadaci u koloni "%s" i stazi "%s" će biti zatvoreni.',
    'Close all tasks in this column and this swimlane' => 'Zatvori sve zadatke u ovoj koloni i ovoj stazi',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nijedan dodatak nije registrovao metodu obaveštavanja o projektu. U korisničkom profilu i dalje možete da konfigurišete pojedinačna obaveštenja.',
    'My dashboard' => 'Moja komandna tabla',
    'My profile' => 'Moj profil',
    'Project owner: ' => 'Vlasnik projekta: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifikator projekta je opcion, mora biti alfanumerički, na primer: MOJPROJEKAT.',
    'Project owner' => 'Vlasnik projekta',
    'Personal projects do not have users and groups management.' => 'Lični projekti nemaju upravljanje korisnicima i grupama.',
    'There is no project member.' => 'Nema članova projekta.',
    'Priority' => 'Prioritet',
    'Task priority' => 'Prioritet zadatka',
    'General' => 'Opšte',
    'Dates' => 'Datumi',
    'Default priority' => 'Podrazumijevani prioritet',
    'Lowest priority' => 'Najmanji prioritet',
    'Highest priority' => 'Najveći prioritet',
    'Close a task when there is no activity' => 'Zatvori zadatak kada nema aktivnosti',
    'Duration in days' => 'Dužina trajanja u danima',
    'Send email when there is no activity on a task' => 'Pošalji email kada nema aktivnosti na zadatku',
    'Unable to fetch link information.' => 'Ne mogu da pribavim informacije o vezi.',
    'Daily background job for tasks' => 'Dnevni pozadinski poslovi za zadatke',
    'Auto' => 'Automatski',
    'Related' => 'Povezan',
    'Attachment' => 'Priložak',
    'Title not found' => 'Bez naslova',
    'Web Link' => 'Veb link',
    'External links' => 'Spoljne veze',
    'Add external link' => 'Dodaj spoljnu vezu',
    'Type' => 'Vrsta',
    'Dependency' => 'Zavisnost',
    'Add internal link' => 'Dodaj unutrašnju vezu',
    'Add a new external link' => 'Dodaj novu spoljnu vezu',
    'Edit external link' => 'Uredi spoljnu vezu',
    'External link' => 'Spoljna veza',
    'Copy and paste your link here...' => 'Kopirajte i zalepite Vašu vezu ovde...',
    'URL' => 'URL',
    'Internal links' => 'Unutrašnje veze',
    'Assign to me' => 'Dodeli meni',
    'Me' => 'Ja',
    'Do not duplicate anything' => 'Ništa ne dupliraj',
    'Projects management' => 'Upravljanje projektima',
    'Users management' => 'Upravljanje korisnicima',
    'Groups management' => 'Upravljanje grupama',
    'Create from another project' => 'Napravi iz drugog projekta',
    'open' => 'otvoreno',
    'closed' => 'zatvoreno',
    'Priority:' => 'Prioritet:',
    'Reference:' => 'Referenca:',
    'Complexity:' => 'Složenost:',
    'Swimlane:' => 'Staza:',
    'Column:' => 'Kolona:',
    'Position:' => 'Pozicija:',
    'Creator:' => 'Kreator:',
    'Time estimated:' => 'Očekivano vreme:',
    '%s hours' => '%s sati',
    'Time spent:' => 'Utrošeno vreme:',
    'Created:' => 'Kreirano:',
    'Modified:' => 'Uređeno:',
    'Completed:' => 'Završeno:',
    'Started:' => 'Započeto:',
    'Moved:' => 'Pomereno:',
    'Task #%d' => 'Zadatak #%d',
    'Time format' => 'Format vremena',
    'Start date: ' => 'Početni datum:',
    'End date: ' => 'Krajnji datum:',
    'New due date: ' => 'Novi rok završetka:',
    'Start date changed: ' => 'Početni datum promenjen: ',
    'Disable personal projects' => 'Onemogući lične projekte',
    'Do you really want to remove this custom filter: "%s"?' => 'Da li zaista želite da uklonite ovaj prilagođeni filter "%s"?',
    'Remove a custom filter' => 'Ukloni prilagođeni filter',
    'User activated successfully.' => 'Korisnik uspešno aktiviran.',
    'Unable to enable this user.' => 'Nije moguće omogućiti ovog korisnika.',
    'User disabled successfully.' => 'Korisnik uspešno onemogućen.',
    'Unable to disable this user.' => 'Nije moguće onemogućiti ovog korisnika.',
    'All files have been uploaded successfully.' => 'Sve datoteke su uspešno otpremljene.',
    'The maximum allowed file size is %sB.' => 'Maksimalna dozvoljena veličina datoteke je %sB.',
    'Drag and drop your files here' => 'Prevucite i spustite Vaše datoteke ovde',
    'choose files' => 'izaberite datoteke',
    'View profile' => 'Pregledaj profil',
    'Two Factor' => 'Dva faktora',
    'Disable user' => 'Onemogući korisnika',
    'Do you really want to disable this user: "%s"?' => 'Da li zaista želite da onemogućite ovog korisnika: "%s"?',
    'Enable user' => 'Omogući korisnika',
    'Do you really want to enable this user: "%s"?' => 'Da li zaista želite omogućite ovog korisnika: "%s"?',
    'Download' => 'Preuzeto',
    'Uploaded: %s' => 'Otpremljeno: %s',
    'Size: %s' => 'Veličina: %s',
    'Uploaded by %s' => 'Otpremio %s',
    'Filename' => 'Ime datoteke',
    'Size' => 'Veličina',
    'Column created successfully.' => 'Kolona uspešno napravljena.',
    'Another column with the same name exists in the project' => 'Već postoji kolona sa istim imenom u ovom projektu.',
    'Default filters' => 'Podrazumevani filteri',
    'Your board doesn\'t have any columns!' => 'Tvoja tabla nema ni jednu kolonu!',
    'Change column position' => 'Promeni poziciju kolone',
    'Switch to the project overview' => 'Prebacivanje na pregled projekta',
    'User filters' => 'Fliteri korisnika',
    'Category filters' => 'Fliteri kategorija',
    'Upload a file' => 'Otpremi datoteku',
    'View file' => 'Pogledaj datoteku',
    'Last activity' => 'Posljednja aktivnost',
    'Change subtask position' => 'Promijeni poziciju podzadatka',
    'This value must be greater than %d' => 'Ova vrednost mora biti veća od %d',
    'Another swimlane with the same name exists in the project' => 'Već postoji staza sa istim imenom u ovom projektu',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Na primer: https://example.kanboard.org/ (koristi se za generisanje apsolutnog URL-a)',
    'Actions duplicated successfully.' => 'Akcije uspješno duplirane.',
    'Unable to duplicate actions.' => 'Nije moguće duplirati akcije.',
    'Add a new action' => 'Dodaj novu akciju',
    'Import from another project' => 'Uvezi iz drugog projekta',
    'There is no action at the moment.' => 'Trenutno nema akcija.',
    'Import actions from another project' => 'Uvezi akcije iz drugog projekta',
    'There is no available project.' => 'Trenutno nema dostupnih projekata.',
    'Local File' => 'Lokalna datoteka',
    'Configuration' => 'Konfiguracija',
    'PHP version:' => 'Verzija PHP-a:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Verzija OS-a:',
    'Database version:' => 'Verzija baze podataka:',
    'Browser:' => 'Pregledač:',
    'Task view' => 'Pregled zadatka',
    'Edit task' => 'Uredi zadatak',
    'Edit description' => 'Uredi opis',
    'New internal link' => 'Nova unutrašnja veza',
    'Display list of keyboard shortcuts' => 'Prikaži listu prečica na tastaturi',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Otpremi sliku za avatar',
    'Remove my image' => 'Ukloni moju sliku',
    'The OAuth2 state parameter is invalid' => 'Parametar stanja OAuth2 je nevažeći',
    'User not found.' => 'Korisnik nije pronađen.',
    'Search in activity stream' => 'Pretraži aktivnosti',
    'My activities' => 'Moje aktivnosti',
    'Activity until yesterday' => 'Aktivnosti do juče',
    'Activity until today' => 'Aktivnosti do danas',
    'Search by creator: ' => 'Pretraga po kreatoru: ',
    'Search by creation date: ' => 'Pretraga po datumu kreiranja: ',
    'Search by task status: ' => 'Pretraga po statusu zadatka: ',
    'Search by task title: ' => 'Pretraga po naslovu zadatka: ',
    'Activity stream search' => 'Pretraga aktivnosti',
    'Projects where "%s" is manager' => 'Projekti gde je "%s" menadžer',
    'Projects where "%s" is member' => 'Projekti gde je "%s" član',
    'Open tasks assigned to "%s"' => 'Otvoreni zadaci dodeljeni "%s"',
    'Closed tasks assigned to "%s"' => 'Zatvoreni zadaci dodijeljeni "%s"',
    'Assign automatically a color based on a priority' => 'Dodeli boju automatski bazirano na prioritetu',
    'Overdue tasks for the project(s) "%s"' => 'Zadaci koji kasne za projekat/projekte "%s"',
    'Upload files' => 'Otpremi datoteke',
    'Installed Plugins' => 'Instalirani dodaci',
    'Plugin Directory' => 'Direktorijum dodataka',
    'Plugin installed successfully.' => 'Dodatak je uspešno instaliran.',
    'Plugin updated successfully.' => 'Dodatak je uspešno ažuriran.',
    'Plugin removed successfully.' => 'Dodatak uspešno uklonjen.',
    'Subtask converted to task successfully.' => 'Podzadatak uspešno pretvoren u zadatak.',
    'Unable to convert the subtask.' => 'Nije moguće pretvoriti podzadatak.',
    'Unable to extract plugin archive.' => 'Nije moguće otpakovati arhivu dodatka.',
    'Plugin not found.' => 'Dodatak nije pronađen.',
    'You don\'t have the permission to remove this plugin.' => 'Nemate dozvolu za uklanjanje ovog dodatka.',
    'Unable to download plugin archive.' => 'Nije moguće preuzeti arhivu dodatka.',
    'Unable to write temporary file for plugin.' => 'Nije moguće zapisati privremenu datoteku za dodatak.',
    'Unable to open plugin archive.' => 'Nije moguće otvoriti arhivu dodatka.',
    'There is no file in the plugin archive.' => 'Nema datoteke u arhivi dodatka.',
    'Create tasks in bulk' => 'Masovno kreiranja zadataka',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Ova Kanboard nije konfigurisan tako da podržava instalaciju dodataka kroz korisničko okruženje.',
    'There is no plugin available.' => 'Nema dostupnih dodataka.',
    'Install' => 'Instaliraj',
    'Update' => 'Ažuriraj',
    'Up to date' => 'Ažurno',
    'Not available' => 'Nije dostupno',
    'Remove plugin' => 'Ukloni dodatak',
    'Do you really want to remove this plugin: "%s"?' => 'Da li zaista želite da uklonite ovaj dodatak: "%s"?',
    'Uninstall' => 'Deinstaliraj',
    'Listing' => 'Spisak',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Upravljanje projektima',
    'Convert to task' => 'Pretvori u zadatak',
    'Convert sub-task to task' => 'Pretvori podzadatak u zadatak',
    'Do you really want to convert this sub-task to a task?' => 'Da li zaista želite da pretvorite podzadatak u zadatak?',
    'My task title' => 'Naslov zadatka',
    'Enter one task by line.' => 'Unesi jedan zadatak po liniji.',
    'Number of failed login:' => 'Broj neuspešnih prijava:',
    'Account locked until:' => 'Korisnički nalog zaključan do:',
    'Email settings' => 'Postavke email-a',
    'Email sender address' => 'Email adresa pošiljaoca',
    'Email transport' => 'Transport email-a',
    'Webhook token' => 'Webhook token',
    'Project tags management' => 'Upravljanje oznakama projekta',
    'Tag created successfully.' => 'Oznaka uspešno kreirana.',
    'Unable to create this tag.' => 'Nije moguće kreirati oznaku.',
    'Tag updated successfully.' => 'Oznaka uspešno ažurirana.',
    'Unable to update this tag.' => 'Nije moguće ažurirati ovu oznaku.',
    'Tag removed successfully.' => 'Oznaka uspešno uklonjena.',
    'Unable to remove this tag.' => 'Nije moguće ukloniti ovu oznaku.',
    'Global tags management' => 'Globalno upravljanje oznakama.',
    'Tags' => 'Oznake',
    'Tags management' => 'Upravljanje oznakama',
    'Add new tag' => 'Dodaj novu oznaku',
    'Edit a tag' => 'Uredi oznaku',
    'Project tags' => 'Oznake projekta',
    'There is no specific tag for this project at the moment.' => 'Trenutno nema oznaka za ovaj projekat.',
    'Tag' => 'Oznaka',
    'Remove a tag' => 'Ukloni oznaku',
    'Do you really want to remove this tag: "%s"?' => 'Da li zaista želite da uklonite ovu oznaku: "%s"?',
    'Global tags' => 'Globalne oznake',
    'There is no global tag at the moment.' => 'Trenutno nema globalnih oznaka.',
    'This field cannot be empty' => 'Ovo polje ne može biti prazno',
    'Close a task when there is no activity in a specific column' => 'Zatvori zadatak kada nema aktivnosti u odabranoj koloni',
    '%s removed a subtask for the task #%d' => '%s je uklonio/la podzadatak za zadatak #%d',
    '%s removed a comment on the task #%d' => '%s je uklonio/la komentar na zadatku #%d',
    'Comment removed on task #%d' => 'Komentar ukloljen na zadatku #%d',
    'Subtask removed on task #%d' => 'Podzadatak ukloljen na zadatku #%d',
    'Hide tasks in this column in the dashboard' => 'Sakrijte zadatke u ovoj koloni na kontrolnoj tabli',
    '%s removed a comment on the task %s' => '%s je uklonio/la komentar za zadatak %s',
    '%s removed a subtask for the task %s' => '%s je uklonio/la podzadatak za zadatak %s',
    'Comment removed' => 'Komentar uklonjen',
    'Subtask removed' => 'Podzadatak uklonjen',
    '%s set a new internal link for the task #%d' => '%s je postavio/la novu unutrašnju vezu za zadatak #%d',
    '%s removed an internal link for the task #%d' => '%s je uklonio/la unutrašnju vezu za zadatak #%d',
    'A new internal link for the task #%d has been defined' => 'Nova unutrašnja veza za zadatak #%d je definisana',
    'Internal link removed for the task #%d' => 'Unutrašnja veza je uklonjena za zadatak #%d',
    '%s set a new internal link for the task %s' => '%s je dodao/la novu unutrašnju vezu za zadatak %s',
    '%s removed an internal link for the task %s' => '%s je uklonio/la unutrašnju vezu za zadatak %s',
    'Automatically set the due date on task creation' => 'Automatski dodaj rok završetka na kreiranom zadatku',
    'Move the task to another column when closed' => 'Pomeri zadatak u drugu kolonu kada je zatvoren',
    'Move the task to another column when not moved during a given period' => 'Pomeri zadatak u drugu kolonu kada nema pomeranja zadatka za zadati period',
    'Dashboard for %s' => 'Komandna tabla - %s',
    'Tasks overview for %s' => 'Pregled zadataka za %s',
    'Subtasks overview for %s' => 'Pregled podzadataka za %s',
    'Projects overview for %s' => 'Pregled projekata za %s',
    'Activity stream for %s' => 'Tok aktivnosti za %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Dodeli boju kada je zadatak pomeren u određenu stazu',
    'Assign a priority when the task is moved to a specific swimlane' => 'Dodeli prioritet kada je zadatak pomeren u određenu stazu',
    'User unlocked successfully.' => 'Korisnik je uspešno otključan.',
    'Unable to unlock the user.' => 'Nije moguće otključati korisnika.',
    'Move a task to another swimlane' => 'Pomeri zadatak u drugu stazu',
    'Creator Name' => 'Ime kreatora',
    'Time spent and estimated' => 'Utrošeno i procenjeno vrieme',
    'Move position' => 'Mesto pomeranja',
    'Move task to another position on the board' => 'Pomeri zadataka na drugo mesto na tabli',
    'Insert before this task' => 'Umetni pre ovog zadatka',
    'Insert after this task' => 'Umetni posle ovog zadatka',
    'Unlock this user' => 'Otključaj ovog korisnika',
    'Custom Project Roles' => 'Prilagođne uloge projekta',
    'Add a new custom role' => 'Dodaj novu prilagođenu ulogu',
    'Restrictions for the role "%s"' => 'Ograničenja za ulogu "%s"',
    'Add a new project restriction' => 'Dodaj nova ograničenja na projektu',
    'Add a new drag and drop restriction' => 'Dodaj nova "prevuci i spusti" ograničenja',
    'Add a new column restriction' => 'Dodaj nova ograničenja za kolonu',
    'Edit this role' => 'Uredi ovu ulogu',
    'Remove this role' => 'Ukloni ovu ulogu',
    'There is no restriction for this role.' => 'Nema ograničenja za ovu ulogu.',
    'Only moving task between those columns is permitted' => 'Samo između ovih kolona je dozvoljeno pomeranje',
    'Close a task in a specific column when not moved during a given period' => 'Zatvori zadatak u odabranoj koloni kada nema pomeranja za zadati period',
    'Edit columns' => 'Uredi kolone',
    'The column restriction has been created successfully.' => 'Ograničenje za kolonu su uspešno kreiranao.',
    'Unable to create this column restriction.' => 'Nemoguće kreirati ograničenja za kolonu.',
    'Column restriction removed successfully.' => 'Ograničenje za kolonu su uspešno uklonjeno.',
    'Unable to remove this restriction.' => 'Nije moguće ukloniti ovo ograničenje.',
    'Your custom project role has been created successfully.' => 'Tvoja prilagođena uloga na projekatu je uspešno kreirana.',
    'Unable to create custom project role.' => 'Nije moguće kreirati prilagođenu ulogu na projektu.',
    'Your custom project role has been updated successfully.' => 'Tvoja prilagođena uloga na projekatu je uspešno ažurirana.',
    'Unable to update custom project role.' => 'Nije moguće ažurirati prilagođenu ulogu na projektu.',
    'Custom project role removed successfully.' => 'Prilagođena uloga na projektu uspešno uklonjena.',
    'Unable to remove this project role.' => 'Nije moguće ukloniti ovu ulogu na projektu.',
    'The project restriction has been created successfully.' => 'Ograničenje na projektu uspešno kreirano.',
    'Unable to create this project restriction.' => 'Nije moguće kreirati ovo ograničenje na projektu.',
    'Project restriction removed successfully.' => 'Ograničenje na projektu uspešno uklonjeno.',
    'You cannot create tasks in this column.' => 'Ne možete kreirati zadatak u ovoj koloni.',
    'Task creation is permitted for this column' => 'Kreiranje zadatka u ovoj koloni je zabranjeno',
    'Closing or opening a task is permitted for this column' => 'Zatvaranje ili otvaranje zadatka u ovoj koloni je zabranjeno',
    'Task creation is blocked for this column' => 'Kreiranje zadatka je onemogućeno za ovu kolonu',
    'Closing or opening a task is blocked for this column' => 'Zatvaranje ili otvaranje zadatka u ovoj koloni je onemogućeno',
    'Task creation is not permitted' => 'Kreiranje zadatka nije dozvoljeno',
    'Closing or opening a task is not permitted' => 'Zatvarnaje ili otvaranje zadatka nije dozvoljeno',
    'New drag and drop restriction for the role "%s"' => 'Novo "prevuci i spusti" ograničenje za ulogu "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Osobe kojima se dodeli ova uloga će biti u mogućnosti da pomeraju zadatke samo imeđu izvorne i odredišne kolone.',
    'Remove a column restriction' => 'Ukloni ograničenje za kolonu',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Da li zaista želite da uklonite ovo ograničenje za kolonu: "%s" u "%s"?',
    'New column restriction for the role "%s"' => 'Novo ograničenje za kolonu za ulogu "%s"',
    'Rule' => 'Pravilo',
    'Do you really want to remove this column restriction?' => 'Da li zaista želite daukloniti ovo ograničenje za kolonu?',
    'Custom roles' => 'Prilagođene uloge',
    'New custom project role' => 'Nova prilagođena uloga za projekat',
    'Edit custom project role' => 'Uredi prilagođenu ulogu za projekat',
    'Remove a custom role' => 'Ukloni prilagođenu ulogu',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Da li zaista želite da uklonite ovu prilagođenu ulogu: "%s"? Sve osobe kojima je dodeljena ova uloga će postati članovi projekta.',
    'There is no custom role for this project.' => 'Nema prilagođenih uloga za ovaj projekat.',
    'New project restriction for the role "%s"' => 'Novo ograničenje na projektu za ulogu "%s"',
    'Restriction' => 'Ograničenje',
    'Remove a project restriction' => 'Ukloni ograničenje na projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'Da li zaista želite da ukloniti ovo ograničenje na projektu: "%s"?',
    'Duplicate to multiple projects' => 'Dupliraj u više projekata',
    'This field is required' => 'Ovo polje je obavezno',
    'Moving a task is not permitted' => 'Pomeranje zadatka nije dozvoljeno',
    'This value must be in the range %d to %d' => 'Ova vrednost mora biti u rasponu od %d do %d',
    'You are not allowed to move this task.' => 'Nemaš dozvolu za pomeranje ovog zadatka.',
    'API User Access' => 'API Pristup korisnika',
    'Preview' => 'Pregled',
    'Write' => 'Piši',
    'Write your text in Markdown' => 'Upiši tekst u Markdown-u',
    'No personal API access token registered.' => 'Nije registrovan lični API pristupni token',
    'Your personal API access token is "%s"' => 'Vaš lični API token za pristup je: "%s"',
    'Remove your token' => 'Uklonite Vaš token',
    'Generate a new token' => 'Generiši novi token',
    'Showing %d-%d of %d' => 'Prikaži %d-%d od %d',
    'Outgoing Emails' => 'Odlazni email-ovi',
    'Add or change currency rate' => 'Dodajte ili promenite kurs valute',
    'Reference currency: %s' => 'Referentna valuta: %s',
    'Add custom filters' => 'Dodaj prilagođene filtere',
    'Export' => 'Izvezi',
    'Add link label' => 'Dodaj etiketu na vezu',
    'Incompatible Plugins' => 'Nekompatibilni dodaci',
    'Compatibility' => 'Kompatibilnost',
    'Permissions and ownership' => 'Dozvole i vlasništvo',
    'Priorities' => 'Prioriteti',
    'Close this window' => 'Zatvori ovaj prozor',
    'Unable to upload this file.' => 'Nije moguće optremiti ovu datoteku.',
    'Import tasks' => 'Uvezi zadatke',
    'Choose a project' => 'Izaberi projekat',
    'Profile' => 'Profil',
    'Application role' => 'Uloga u aplikaciji',
    '%d invitations were sent.' => '%d poslato pozivnica.',
    '%d invitation was sent.' => '%d pozivnica poslata.',
    'Unable to create this user.' => 'Nije moguće kreirati ovog korisnika.',
    'Kanboard Invitation' => 'Kanboard pozivnica',
    'Visible on dashboard' => 'Vidljivo na komandnoj tabli',
    'Created at:' => 'Kreirano:',
    'Updated at:' => 'Ažurirano:',
    'There is no custom filter.' => 'Nema prilagođenih filtera.',
    'New User' => 'Novi korisnik',
    'Authentication' => 'Autentifikacija',
    'If checked, this user will use a third-party system for authentication.' => 'Ako je označeno, ovaj korisnik će koristiti nezavisni sistem za autentifikaciju.',
    'The password is necessary only for local users.' => 'Lozinka je neophodna samo za lokalne korisnike.',
    'You have been invited to register on Kanboard.' => 'Pozvani ste da se registrujete na Kanboard.',
    'Click here to join your team' => 'Kliknite ovde da se prodružite Vašem timu',
    'Invite people' => 'Pozovi ljude',
    'Emails' => 'email-ovi',
    'Enter one email address by line.' => 'Unesi jednu email adresu po redu.',
    'Add these people to this project' => 'Dodaj ove ljude u ovaj projekat',
    'Add this person to this project' => 'Dodaj ovu osobu u ovaj projekat',
    'Sign-up' => 'Registracija',
    'Credentials' => 'Pristupni podaci',
    'New user' => 'Novi korisnik',
    'This username is already taken' => 'Ovo korisničko ime je zauzeto',
    'Your profile must have a valid email address.' => 'Profil mora imati validnu email adresu.',
    'TRL - Turkish Lira' => 'TRL - Turska Lira',
    'The project email is optional and could be used by several plugins.' => 'email projekta je opcion i može je koristiti nekoliko dodataka.',
    'The project email must be unique across all projects' => 'email projekta mora biti jedinstven za svaki projekat',
    'The email configuration has been disabled by the administrator.' => 'Uređivanje email-a je onemogućeno od strane administratora.',
    'Close this project' => 'Zatvori ovaj projekat',
    'Open this project' => 'Otvori ovaj projekat',
    'Close a project' => 'Zatvori projekat',
    'Do you really want to close this project: "%s"?' => 'Da li zaista želite da zatvorite projekat: "%s"?',
    'Reopen a project' => 'Ponovo otvori projekat',
    'Do you really want to reopen this project: "%s"?' => 'Da li zaista želite da ponovo otvoriti projekat: "%s"?',
    'This project is open' => 'Ovaj projekat je otvoren',
    'This project is closed' => 'Ovaj projekat je zatvoren',
    'Unable to upload files, check the permissions of your data folder.' => 'Nije moguće otpremiti datoteke, proverite prava na direktorijum servera.',
    'Another category with the same name exists in this project' => 'Kategorija sa ovim imenom već postoji na ovom projektu',
    'Comment sent by email successfully.' => 'Komentar je uspešno poslat email-om.',
    'Sent by email to "%s" (%s)' => 'Poslato email-om na "%s" (%s)',
    'Unable to read uploaded file.' => 'Nije moguće pročitati otpremljenu datoteku.',
    'Database uploaded successfully.' => 'Baza podataka je uspešno otpremljena.',
    'Task sent by email successfully.' => 'Zadatak je uspešno poslat email-om.',
    'There is no category in this project.' => 'Nema kategorija u ovom projektu.',
    'Send by email' => 'Pošalji email-om',
    'Create and send a comment by email' => 'Napravi i pošalji komentar email-om',
    'Subject' => 'Predmet',
    'Upload the database' => 'Otpremi bazu podataka',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Možete otpremiti prethodno preuzetu Sqlite bazu podataka (Gzip format).',
    'Database file' => 'Datoteka baze podataka',
    'Upload' => 'Otpremi',
    'Your project must have at least one active swimlane.' => 'Projekat mora imati barem jednu aktivnu stazu.',
    'Project: %s' => 'Projekat: %s',
    'Automatic action not found: "%s"' => 'Automatska akcija nije pronađena: "%s"',
    '%d projects' => '%d projekata',
    '%d project' => '%d projekat',
    'There is no project.' => 'Nema projekta.',
    'Sort' => 'Sortiraj',
    'Project ID' => 'ID projekta',
    'Project name' => 'Naziv projekta',
    'Public' => 'Javno',
    'Personal' => 'Lično',
    '%d tasks' => '%d zadataka',
    '%d task' => '%d zadatak',
    'Task ID' => 'ID zadatka',
    'Assign automatically a color when due date is expired' => 'Automatski postavi boju kada je rok završetka istekao',
    'Total score in this column across all swimlanes' => 'Ukupni rezultat u ovoj koloni za sve staze',
    'HRK - Kuna' => 'HRK - Hrvatska Kuna',
    'ARS - Argentine Peso' => 'ARS - Argentiski pezos',
    'COP - Colombian Peso' => 'COP - Kolumbijski pezos',
    '%d groups' => '%d grupe',
    '%d group' => '%d grupa',
    'Group ID' => 'ID grupe',
    'External ID' => 'Spoljni ID',
    '%d users' => '%d korisnika',
    '%d user' => '%d korisnik',
    'Hide subtasks' => 'Sakrij podzadatke',
    'Show subtasks' => 'Prikaži podzadatke',
    'Authentication Parameters' => 'Parametri za atentifikaciju',
    'API Access' => 'API pristup',
    'No users found.' => 'Nema ponađenih korisnika.',
    'User ID' => 'ID korisnika',
    'Notifications are activated' => 'Notifikacije su omogućene',
    'Notifications are disabled' => 'Notifikacije su onemogućene',
    'User disabled' => 'Korisnik je onemogućen',
    '%d notifications' => '%d notifkacija/e',
    '%d notification' => '%d notifikacija',
    'There is no external integration installed.' => 'Nije instalirana spoljna integracija.',
    'You are not allowed to update tasks assigned to someone else.' => 'Nije vam dozvoljeno da ažurirate zadatke dodeljene nekom drugom.',
    'You are not allowed to change the assignee.' => 'Nije vam dozvoljeno da promenite izvršioca.',
    'Task suppression is not permitted' => 'Suzbijanje zadataka nije dozvoljeno',
    'Changing assignee is not permitted' => 'Menjanje izvršioca nije dozvoljeno',
    'Update only assigned tasks is permitted' => 'Dozvoljeno je ažuriranje samo dodeljenih zadataka',
    'Only for tasks assigned to the current user' => 'Samo za zadatke dodeljene trenutnom korisniku',
    'My projects' => 'Moji projekti',
    'You are not a member of any project.' => 'Niste član nijednog projekta.',
    'My subtasks' => 'Moji podzadaci.',
    '%d subtasks' => '%d podzadataka',
    '%d subtask' => '%d podzadatak',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Samo premeštanja zadatka između tih kolona je dozvoljeno za zadatke dodeljene trenutnom korisniku',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Danska kruna',
    'Remove user from group' => 'Ukloni korisnika iz grupe',
    'Assign the task to its creator' => 'Dodeli zadatak njegovom kreatoru',
    'This task was sent by email to "%s" with subject "%s".' => 'Ovaj zadatak je poslat email-om na "%s" sa predmetom "%s".',
    'Predefined Email Subjects' => 'Unapred definisani predmeti e-pošte',
    'Write one subject by line.' => 'Unesite jedan predmet po liniji',
    'Create another link' => 'Napravi još jednu vezu',
    'BRL - Brazilian Real' => 'BRL - Brazilski real',
    'Add a new Kanboard task' => 'Dodajte novi Kanboard zadatak',
    'Subtask not started' => 'Podzadatak nije započet',
    'Subtask currently in progress' => 'Podzadatak je trenutno u toku',
    'Subtask completed' => 'Podzadatak završen',
    'Subtask added successfully.' => 'Podzadatak uspešno dodat.',
    '%d subtasks added successfully.' => '%d podzadataka uspešno dodato.',
    'Enter one subtask by line.' => 'Unesite jedan podzadatak po liniji.',
    'Predefined Contents' => 'Predefnisani sadržaj',
    'Predefined contents' => 'Predefnisani sadržaj',
    'Predefined Task Description' => 'Predefinisan opis zadatka',
    'Do you really want to remove this template? "%s"' => 'Da li zaista želite da uklonite ovaj šablon? "%s"',
    'Add predefined task description' => 'Dodat predefinsani opis zadatka',
    'Predefined Task Descriptions' => 'Predefinisani opis zadatka',
    'Template created successfully.' => 'Šablon uspešno kreiran',
    'Unable to create this template.' => 'Nije moguće kreirati ovaj šablon',
    'Template updated successfully.' => 'Šablon uspešno ažuriran',
    'Unable to update this template.' => 'Nije moguće ažurirati ovaj šablon',
    'Template removed successfully.' => 'Šablon uspešno uklonjen',
    'Unable to remove this template.' => 'Nije moguće ukloniti ovaj šablon',
    'Template for the task description' => 'Šablon za opis zadatka',
    'The start date is greater than the end date' => 'Početni datum je veći od kranjeg datuma',
    'Tags must be separated by a comma' => 'Oznake moraju biti razdvojene zarezom',
    'Only the task title is required' => 'Samo naslov zadatka je obavezan',
    'Creator Username' => 'Korisničko ime kreatora',
    'Color Name' => 'Boja kolone',
    'Column Name' => 'Naziv kolone',
    'Swimlane Name' => 'Naziv staze',
    'Time Estimated' => 'Procenjeno vreme',
    'Time Spent' => 'Utrošeno vreme',
    'External Link' => 'Spoljna veza',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ova funckionalnost omogućava iCal kanal, RSS kanal i prikaz javne table.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zaustavi tajmer na svim podzadacima prilikom premeštanja zadatka u drugu kolonu',
    'Subtask Title' => 'Naslov podzadatka',
    'Add a subtask and activate the timer when moving a task to another column' => 'Dodaj podzadatak i aktiviraj tajmer prilikom premeštanja zadatka u drugu kolonu',
    'days' => 'dana',
    'minutes' => 'minuta',
    'seconds' => 'sekundi',
    'Assign automatically a color when preset start date is reached' => 'Automatski postavi boju kada se dostigne unapred zadati datum početka',
    'Move the task to another column once a predefined start date is reached' => 'Premestite zadatak u drugu kolonu kada se dostigne unapred definisani datum početka',
    'This task is now linked to the task %s with the relation "%s"' => 'Zadatak je sada povezan sa zadatkom %s sa relacijom "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Veza sa relacijom "%s" sa zadatkom %s je uklonjena',
    'Custom Filter:' => 'Prilagođeni filter',
    'Unable to find this group.' => 'Nije moguće pronaći ovu grupu.',
    '%s moved the task #%d to the column "%s"' => '%s je pomerio/la zadatak #%d u kolonu "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s je pomerio/la zadatakk #%d na poziciju %d u koloni "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s je pomerio/la zadatak #%d u stazu "%s"',
    '%sh spent' => '%sč potrošeno',
    '%sh estimated' => '%sč procenjeno',
    'Select All' => 'Izaberi sve',
    'Unselect All' => 'Poništi sve',
    'Apply action' => 'Primeni akciju',
    'Move selected tasks to another column or swimlane' => 'Pomerei odabrani zadatak u neku drugu kolonu ili stazu',
    'Edit tasks in bulk' => 'Masovno uređivanje zadataka',
    'Choose the properties that you would like to change for the selected tasks.' => 'Izaberite svojstva koja biste želeli da promenite za izabrane zadatke.',
    'Configure this project' => 'Konfigurišite ovaj projekat',
    'Start now' => 'Započni sada',
    '%s removed a file from the task #%d' => '%s je uklonio/la dataoteku iz zadatka #%d',
    'Attachment removed from task #%d: %s' => 'Dodatak je uklonjen iz zadatka #%d: %s',
    'No color' => 'Nema boju',
    'Attachment removed "%s"' => 'Priložak uklonjen "%s"',
    '%s removed a file from the task %s' => '%s je uklonio/la datoteku iz zadatka %s',
    'Move the task to another swimlane when assigned to a user' => 'Premesti zadatak u drugu stazu kada je zadatak dodeljen korisniku',
    'Destination swimlane' => 'Odredišna staza',
    'Assign a category when the task is moved to a specific swimlane' => 'Postavi kategoriju kada je zadatak premešten u određenu stazu',
    'Move the task to another swimlane when the category is changed' => 'Premesti zadatak u drugu stazu kada se promeni kategorija',
    'Reorder this column by priority (ASC)' => 'Promenite redosled ove kolone prema prioritetu (UZLAZNO)',
    'Reorder this column by priority (DESC)' => 'Promenite redosled ove kolone prema prioritetu (SILAZNO)',
    'Reorder this column by assignee and priority (ASC)' => 'Promenite redosled ove kolone prema izvršiocu (UZLAZNO)',
    'Reorder this column by assignee and priority (DESC)' => 'Promenite redosled ove kolone prema izvršiocu (SILAZNO)',
    'Reorder this column by assignee (A-Z)' => 'Promenite redosled ove kolone prema izvršiocu (A-Ž)',
    'Reorder this column by assignee (Z-A)' => 'Promenite redosled ove kolone prema izvršiocu (Ž-A)',
    'Reorder this column by due date (ASC)' => 'Promenite redosled ove kolone prema roku završetka (UZLAZNO)',
    'Reorder this column by due date (DESC)' => 'Promenite redosled ove kolone prema roku završetka (SILAZNO)',
    'Reorder this column by id (ASC)' => 'Promenite redosled ove kolone prema ID-u (UZLAZNO)',
    'Reorder this column by id (DESC)' => 'Promenite redosled ove kolone prema ID-u (SILAZNO)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s je pomerio/la zadatak #%d "%s" u projekat "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premešten u projekat "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Pomeri zadatak u neku drugu kolonu kada je datum roka završetka kraći od određenog broja dana',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automatski ažuriraj datum početka kada se zadatak ukloni iz određene kolone',
    'HTTP Client:' => 'HTTP klijent',
    'Assigned' => 'Dodeljeno',
    'Task limits apply to each swimlane individually' => 'Ograničenje broja zadataka važi za svaku stazu zasebno',
    'Column task limits apply to each swimlane individually' => 'Ograničenje broja zadataka u koloni važi za svaku stazu zasebno',
    'Column task limits are applied to each swimlane individually' => 'Ograničenje broja zadataka u koloni se primenjuje na svaku stazu zasebno',
    'Column task limits are applied across swimlanes' => 'Ograničenje broja zadataka u koloni se primenjuje na više staza',
    'Task limit: ' => 'Ograničenje broja zadataka: ',
    'Change to global tag' => 'Promeni u globalnu oznaku',
    'Do you really want to make the tag "%s" global?' => 'Da li zaista želite da oznaku "%s" učinite globalnom?',
    'Enable global tags for this project' => 'Omogući globalne oznake za ovaj projekat',
    'Group membership(s):' => 'Članstvo u grupi/grupama:',
    '%s is a member of the following group(s): %s' => '%s je član grupa(e): %s',
    '%d/%d group(s) shown' => '%d/%d prikazane grupa(e)',
    'Subtask creation or modification' => 'Kreiranje ili modifikacija podzadatka',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Dodeli zadatak određenom korisnika kada je zadatak prebačen u određenu stazu',
    'Comment' => 'Komentar',
    'Collapse vertically' => 'Skupi vertikalno',
    'Expand vertically' => 'Raširi vertikalno',
    'MXN - Mexican Peso' => 'MXN - Meksički pezos',
    'Estimated vs actual time per column' => 'Procenjeno vreme naspram stvarnog vremena po koloni',
    'HUF - Hungarian Forint' => 'HUF - Mađarska forinta',
    'XBT - Bitcoin' => 'XBT - Bitkoin',
    'You must select a file to upload as your avatar!' => 'Morate izabrati datoteku koju ćete postaviti kao avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste otpremili nije validna slika! (Dozvoljeni su samo *.gif, *.jpg, *.jpeg i *.png formati!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavite rok završetka kada se zadatak premesti iz određene kolone',
    'No other projects found.' => 'Nisu pronađeni drugi projekti.',
    'Please choose a project you want to copy the tasks from.' => 'Molimo izaberite projekat iz kojeg želite da kopirate zadatke.',
    'Import Tasks' => 'Uvoz zadatka',
    'Copy' => 'Kopiraj',
    'Tasks copied successfully.' => 'Zadaci su uspešno iskopirani.',
    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Svetla tema',
    'Dark theme' => 'Tamna tema',
    'Automatic theme - Sync with system' => 'Automatska tema - sinhronizacija sa sistemom',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
